@@ -39,6 +39,7 @@ class ErrorInfo(Error):
     ```
     """
 
+    name = "use-set-discard"
     code = 132
     msg: str = "Replace `if x in s: s.remove(x)` with `s.discard(x)`"
     categories = ["readability", "set"]
@@ -68,4 +69,4 @@ def check(node: IfStmt, errors: list[Error]) -> None:
             and is_equivalent(rhs, expr)
             and str(ty).startswith("builtins.set[")
         ):
-            errors.append(ErrorInfo(node.line, node.column))
+            errors.append(ErrorInfo.from_node(node))
