@@ -31,6 +31,7 @@ class ErrorInfo(Error):
     useful for comparing against a range of constant values.
     """
 
+    name = "use-in-oper"
     code = 108
     categories = ["logical", "readability"]
 
@@ -52,6 +53,4 @@ def check(node: OpExpr, errors: list[Error]) -> None:
     if data := get_common_expr_in_comparison_chain(node, oper="or"):
         expr, indices = data
 
-        errors.append(
-            ErrorInfo(expr.line, expr.column, create_message(indices))
-        )
+        errors.append(ErrorInfo.from_node(expr, create_message(indices)))
