@@ -27,6 +27,7 @@ class ErrorInfo(Error):
     Note: if `x` depends on side-effects, then this check should be ignored.
     """
 
+    name = "use-or-oper"
     code = 110
     msg: str = "Replace `x if x else y` with `x or y`"
     categories = ["logical", "readability"]
@@ -34,4 +35,4 @@ class ErrorInfo(Error):
 
 def check(node: ConditionalExpr, errors: list[Error]) -> None:
     if is_equivalent(node.if_expr, node.cond):
-        errors.append(ErrorInfo(node.line, node.column))
+        errors.append(ErrorInfo.from_node(node))
