@@ -91,9 +91,7 @@ def check(node: OpExpr, errors: list[Error]) -> None:
 
             if fullname and type_name.startswith(fullname):
                 errors.append(
-                    ErrorInfo(
-                        node.line,
-                        node.column,
-                        f"Replace `x or {expr}` with `x`",
+                    ErrorInfo.from_node(
+                        node, f"Replace `x or {expr}` with `x`"
                     )
                 )
