@@ -27,6 +27,7 @@ class ErrorInfo(Error):
     ```
     """
 
+    name = "use-tuple-unpack-swap"
     code = 128
     msg: str = "Use tuple unpacking instead of temporary variables to swap values"  # noqa: E501
     categories = ["readability"]
@@ -61,7 +62,7 @@ def check_stmts(stmts: list[Statement], errors: list[Error]) -> None:
                 ] if (
                     a.name == f.name and b.name == c.name and d.name == e.name
                 ):
-                    errors.append(ErrorInfo(a.line, a.column))
+                    errors.append(ErrorInfo.from_node(a))
 
                     assignments = []
 
