@@ -26,6 +26,7 @@ class ErrorInfo(Error):
     ```
     """
 
+    name = "use-fstring-number-format"
     code = 116
     categories = ["builtin", "fstring"]
 
@@ -47,9 +48,8 @@ def check(node: IndexExpr, errors: list[Error]) -> None:
             fstring = f'f"{{num:{format}}}"'
 
             errors.append(
-                ErrorInfo(
-                    node.line,
-                    node.column,
+                ErrorInfo.from_node(
+                    node,
                     f"Replace `{name_node.name}(num)[2:]` with `{fstring}`",
                 )
             )
